@@ -12,11 +12,12 @@ from .consts import (BASEPATH,
                      LAMBDA, λ,
                      MAXINT,
                      PATH,
-                     PROJECT_NAME,
+                     PROJECT_NAME, PROJECT_PATH,
                      PY3, PYPY,
                      QUALIFIER,
                      SEPARATOR_WIDTH,
                      SINGLETON_TYPES,
+                     SCRIPT_PATH, TEST_PATH,
                      TEXTMATE,
                      TOKEN,
                      VERBOTEN,
@@ -24,6 +25,8 @@ from .consts import (BASEPATH,
                                        XDG_RUNTIME_MODE,
                      NoDefault)
 
+from .data import GREEKOUT
+
 from .enums import System, CSIDL, SYSTEM
 
 from .exceptions import (BadDotpathWarning,
@@ -60,17 +63,19 @@ __all__ = ('BASEPATH',
            'LAMBDA', 'λ',
            'MAXINT',
            'PATH',
-           'PROJECT_NAME',
+           'PROJECT_NAME', 'PROJECT_PATH',
            'PY3', 'PYPY',
            'QUALIFIER',
            'SEPARATOR_WIDTH',
            'SINGLETON_TYPES',
+           'SCRIPT_PATH', 'TEST_PATH',
            'TEXTMATE',
            'TOKEN',
            'VERBOTEN',
            'XDG_RUNTIME_BASE', 'XDG_RUNTIME_DIR',
                                'XDG_RUNTIME_MODE',
            'NoDefault',
+           'GREEKOUT',
            'System', 'CSIDL', 'SYSTEM',
            'BadDotpathWarning',
            'CDBError',
