@@ -3,8 +3,9 @@ from __future__ import print_function
 
 import sys, os
 import warnings
+import weakref
 
-from clu.constants.consts import λ, NoDefault, pytuple
+from clu.constants.consts import λ, φ, NoDefault, pytuple
 from clu.constants.exceptions import ExportError, ExportWarning
 from clu.constants.polyfills import MutableMapping, lru_cache
 
@@ -149,6 +150,10 @@ def path_to_dotpath(path):
     from clu.constants.consts import BASEPATH, QUALIFIER
     from clu.constants.exceptions import BadDotpathWarning
     
+    # Garbage in, garbage out:
+    if path is None:
+        return None
+    
     # Relativize the path to the BASEPATH,
     # and replace slashes with dots:
     relpath = os.path.relpath(path, start=BASEPATH)
@@ -156,7 +161,9 @@ def path_to_dotpath(path):
     
     # Trim off any remaining “.py” suffixes,
     # and extraneous dot-prefixes:
-    if dotpath.endswith('.py'):
+    if dotpath.endswith('.__init__.py'):
+        dotpath = dotpath[:len(dotpath)-12]
+    elif dotpath.endswith('.py'):
         dotpath = dotpath[:len(dotpath)-3]
     while dotpath.startswith(QUALIFIER):
         dotpath = dotpath[1:]
@@ -164,7 +171,7 @@ def path_to_dotpath(path):
     # Warn before returning, if the converted path
     # should contain dashes:
     if '-' in dotpath:
-        warnings.warn("Dotpath contains dashes: “%s”" % dotpath,
+        warnings.warn(f"Dotpath contains dashes: “{dotpath}”",
                       BadDotpathWarning, stacklevel=2)
     
     return dotpath
@@ -179,21 +186,53 @@ def predicates_for_types(*types):
 class Exporter(MutableMapping):
     
     """ A class representing a list of things for a module to export. """
-    __slots__ = pytuple('exports') + ('path', 'dotpath')
+    __slots__ = pytuple('exports', 'weakref') + ('path', 'dotpath')
+    instances = weakref.WeakValueDictionary()
+    
+    def __new__(cls, *args, **kwargs):
+        try:
+            instance = super(Exporter, cls).__new__(cls, *args, **kwargs)
+        except TypeError:
+            instance = super(Exporter, cls).__new__(cls)
+        
+        instance.path = kwargs.pop('path', None)
+        instance.dotpath = path_to_dotpath(instance.path)
+        
+        if instance.dotpath is not None:
+            cls.instances[instance.dotpath] = instance
+        
+        return instance
+    
+    @classmethod
+    def __class_getitem__(cls, key):
+        """ Return a specific Exporter instance from the registry,
+            given a dotted module path, like e.g:
+            
+                from clu import naming
+                assert Exporter['clu.naming'] == naming.exporter
+        """
+        # N.B. you are theoretically “not supposed” to use the
+        # “__class_getitem__” method for anything whatsoever, and
+        # just leave it alone unless you are fucking around with
+        # “typing” module internals. I say fuck that – a) I have
+        # already spent more than enough time fucking around with
+        # “typing” shit and I am not interested at this time, and
+        # b) it’s too useful a method to give it all up. So deal.
+        from clu.typology import isstring
+        if not isstring(key):
+            raise TypeError("instance access by string keys only")
+        return cls.instances[key]
     
     def __init__(self, *args, **kwargs):
         self.__exports__ = {}
         
-        if 'path' in kwargs:
-            self.path = kwargs.pop('path', None)
-            if self.path is not None:
-                self.dotpath = path_to_dotpath(self.path)
-            else:
-                self.dotpath = None
-        
         for arg in args:
-            if isinstance(arg, type(self)):
+            if hasattr(arg, '__exports__'):
                 self.__exports__.update(arg.__exports__)
+            elif hasattr(arg, '_asdict'):
+                self.__exports__.update(arg._asdict())
+            elif hasattr(arg, 'to_dict'):
+                self.__exports__.update(arg.to_dict())
             else:
                 try:
                     d = dict(arg)
@@ -275,7 +314,7 @@ class Exporter(MutableMapping):
         if named is None:
             raise ExportError("can’t export an unnamed thing")
         if named in self.__exports__:
-            raise ExportError("can’t re-export name “%s”" % named)
+            raise ExportError(f"can’t re-export name “{named}”")
         if thing is self.__exports__:
             raise ExportError("can’t export the __exports__ dict directly")
         if thing is self:
@@ -284,14 +323,17 @@ class Exporter(MutableMapping):
         # At this point, “named” is valid -- if we were passed
         # a lambda, try to rename it with either our valid name,
         # or the result of an ID-based search for that lambda:
-        if callable(thing):
-            if getattr(thing, '__name__', '') == λ:
-                if named == λ:
+        if callable(thing) and hasattr(thing, '__name__'):
+            if getattr(thing, '__name__') in (λ, φ):
+                dname = getattr(thing, '__name__')
+                if named in (λ, φ):
                     named = thingname_search(thing)
                 if named is None:
                     raise ExportError(type(self).messages['noname'] % id(thing))
                 thing.__name__ = thing.__qualname__ = named
-                thing.__lambda_name__ = λ # To recall the lambda’s genesis
+                thing.__lambda_name__ = dname # To recall the lambda’s genesis
+                if dname == φ and self.dotpath is not None:
+                    thing.__module__ = str(self.dotpath) # Reset __module__ for phi-types
         
         # If a “doc” argument was passed in, attempt to assign
         # the __doc__ attribute accordingly on the item -- note
@@ -421,7 +463,7 @@ class Exporter(MutableMapping):
     def __bool__(self):
         return len(self.__exports__) > 0
 
-exporter = Exporter()
+exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 export(doctrim)
@@ -448,5 +490,4 @@ def test():
     print()
 
 if __name__ == '__main__':
-    test()
-
+    test()
\ No newline at end of file
