@@ -15,10 +15,10 @@ from distutils.spawn import find_executable
 from functools import wraps
 from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
 
-from clu.constants.consts import DELETE_FLAG, ENCODING, PATH
+from clu.constants.consts import DELETE_FLAG, ENCODING, PATH, SCRIPT_PATH
 from clu.constants.exceptions import ExecutionError, FilesystemError
 from clu.constants.polyfills import lru_cache, scandir, walk
-from clu.predicates import attr, allattrs
+from clu.predicates import attr, allattrs, anyof
 from clu.sanitizer import utf8_encode
 from clu.typology import ispath, isvalidpath
 from .misc import masked_permissions
@@ -35,14 +35,14 @@ DEFAULT_PREFIX = "yo-dogg-"
 def ensure_path_is_valid(pth):
     """ Raise an exception if we can’t write to the specified path """
     if not ispath(pth):
-        raise FilesystemError("Operand must be a path type: %s" % pth)
+        raise FilesystemError(f"Operand must be a path type: {pth}")
     if os.path.exists(pth):
         if os.path.isdir(pth):
-            raise FilesystemError("Can’t save over directory: %s" % pth)
-        raise FilesystemError("Output file exists: %s" % pth)
+            raise FilesystemError(f"Can’t save over directory: {pth}")
+        raise FilesystemError(f"Output file exists: {pth}")
     parent_dir = os.path.dirname(pth)
     if not os.path.isdir(parent_dir):
-        raise FilesystemError("Directory doesn’t exist: %s" % parent_dir)
+        raise FilesystemError(f"Directory doesn’t exist: {parent_dir}")
 
 @export
 def write_to_path(data, pth, relative_to=None, verbose=False):
@@ -61,10 +61,7 @@ def write_to_path(data, pth, relative_to=None, verbose=False):
 @export
 def script_path():
     """ Return the path to the embedded scripts directory. """
-    return os.path.join(
-           os.path.dirname(
-           os.path.dirname(
-           os.path.dirname(__file__))), 'scripts')
+    return SCRIPT_PATH
 
 @export
 def which(binary_name, pathvar=None):
@@ -82,7 +79,7 @@ which.pathvar = PATH
 def back_tick(command,  as_str=True,
                        ret_err=False,
                      raise_err=None, **kwargs):
-    """ Run command `command`, return stdout -- or (stdout, stderr) if `ret_err`.
+    f""" Run command `command`, return stdout -- or (stdout, stderr) if `ret_err`.
         Roughly equivalent to ``check_output`` in Python 2.7.
         
         Parameters
@@ -108,7 +105,7 @@ def back_tick(command,  as_str=True,
             value).
         encoding : str, optional
             The name of the encoding to use when decoding the command output per
-            the `as_str` value. Default is “%s”.
+            the `as_str` value. Default is “{ENCODING}”.
         directory : str / Directory / path-like, optional
             The directory in which to execute the command. Default is None (in
             which case the process working directory, unchanged, will be used).
@@ -133,7 +130,7 @@ def back_tick(command,  as_str=True,
         executed command returns with any non-zero exit status, and `raise_err`
         is set to True.
         
-    """ % ENCODING
+    """
     # Step 1: Prepare for battle:
     import subprocess, shlex
     verbose = bool(kwargs.pop('verbose',  False))
@@ -148,7 +145,7 @@ def back_tick(command,  as_str=True,
         command = shlex.split(command)
     if verbose:
         print("EXECUTING:", file=sys.stdout)
-        print("`{}`".format(command_str),
+        print(f"`{command_str}`",
                             file=sys.stdout)
         print("",           file=sys.stdout)
     process = subprocess.Popen(command, stdout=subprocess.PIPE,
@@ -164,27 +161,28 @@ def back_tick(command,  as_str=True,
     # Step 3: Analyze the return code:
     if returncode is None:
         process.terminate()
-        raise ExecutionError('`{}` terminated without exiting cleanly'.format(command_str))
+        raise ExecutionError(f'`{command_str}` terminated without exiting cleanly')
     if raise_err and returncode != 0:
-        raise ExecutionError('`{}` exited with status {}, error: “{}”'.format(command_str,
-                                   returncode,
-                                   u8str(errors).strip()))
+        error_str = u8str(errors).strip()
+        raise ExecutionError(f'`{command_str}` exited with status {returncode}, error: “{error_str}”')
     # Step 4: Tidy the output and return it:
     if verbose:
         if returncode != 0:
             print("",                           file=sys.stderr)
-            print("NONZERO RETURN STATUS: {}".format(returncode),
+            print(f"NONZERO RETURN STATUS: {returncode}",
                                                 file=sys.stderr)
             print("",                           file=sys.stderr)
         if len(u8str(output.strip())) > 0:
+            output_str = u8str(output).strip()
             print("")
             print("OUTPUT:",                            file=sys.stdout)
-            print("`{}`".format(u8str(output).strip()), file=sys.stdout)
+            print(f"`{output_str}`",                    file=sys.stdout)
             print("",                                   file=sys.stdout)
         if len(u8str(errors.strip())) > 0:
+            error_str = u8str(errors).strip()
             print("",                                   file=sys.stderr)
             print("ERRORS:",                            file=sys.stderr)
-            print("`{}`".format(u8str(errors).strip()), file=sys.stderr)
+            print(f"`{error_str}`",                     file=sys.stderr)
             print("",                                   file=sys.stderr)
     output = output.strip()
     if ret_err:
@@ -234,16 +232,16 @@ def temporary(suffix='', prefix='', parent=None, **kwargs):
     directory = os.fspath(kwargs.pop('dir', parent) or gettempdir())
     if suffix:
         if not suffix.startswith(os.extsep):
-            suffix = "%s%s" % (os.extsep, suffix)
+            suffix = f"{os.extsep}{suffix}"
     tempmade = mktemp(prefix=prefix, suffix=suffix, dir=directory)
     tempsplit = os.path.splitext(os.path.basename(tempmade))
     if not suffix:
         suffix = tempsplit[1][1:]
     if not prefix or kwargs.pop('randomized', False):
         prefix, _ = os.path.splitext(tempsplit[0]) # WTF, HAX!
-    fullpth = os.path.join(directory, "%s%s" % (prefix, suffix))
+    fullpth = os.path.join(directory, f"{prefix}{suffix}")
     if os.path.exists(fullpth):
-        raise FilesystemError("temporary(): file exists: %s" % fullpth)
+        raise FilesystemError(f"temporary(): file exists: {fullpth}")
     return fullpth
 
 class TypeLocker(abc.ABCMeta):
@@ -437,9 +435,9 @@ class TemporaryName(collections.abc.Hashable,
         # regardless of whether or not the default is in use:
         if suffix:
             if not suffix.startswith(os.extsep):
-                suffix = "%s%s" % (os.extsep, suffix)
+                suffix = f"{os.extsep}{suffix}"
         else:
-            suffix = "%stmp" % os.extsep
+            suffix = f"{os.extsep}tmp"
         
         # Try the “parent” argument first, fall back to the “dir”
         # keyword, and normalize with `os.fspath(¬)`:
@@ -560,7 +558,12 @@ class TemporaryName(collections.abc.Hashable,
             if os.path.exists(destination):
                 if os.path.samefile(self._name, destination):
                     raise FilesystemError("Can’t copy to identical locations")
-            return shutil.copy2(self._name, os.fspath(destination))
+                if os.path.isdir(self._name, destination):
+                    raise FilesystemError("Can’t copy files over a directory")
+                rm_rf(destination)
+            return os.path.exists(
+                   shutil.copy2(self._name, os.fspath(destination),
+                                follow_symlinks=True))
         return False
     
     def do_not_destroy(self):
@@ -658,7 +661,7 @@ class Directory(collections.abc.Hashable,
               'will_change',        'did_change',
               'will_change_back',   'did_change_back')
     
-    zip_suffix = "%szip" % os.extsep
+    zip_suffix = f"{os.extsep}zip"
     
     def __init__(self, pth=None):
         """ Initialize a new Directory object.
@@ -903,11 +906,11 @@ class Directory(collections.abc.Hashable,
         """
         pth = self.subpath(subdir, whence, requisite=False)
         if os.path.isfile(pth):
-            raise FilesystemError("file exists at subdirectory path: %s" % pth)
+            raise FilesystemError(f"file exists at subdirectory path: {pth}")
         if os.path.islink(pth):
-            raise FilesystemError("symlink exists at subdirectory path: %s" % pth)
+            raise FilesystemError(f"symlink exists at subdirectory path: {pth}")
         if os.path.ismount(pth):
-            raise FilesystemError("mountpoint exists at subdirectory path: %s" % pth)
+            raise FilesystemError(f"mountpoint exists at subdirectory path: {pth}")
         return self.directory(pth)
     
     def makedirs(self, pth=None, mode=0o755):
@@ -960,15 +963,17 @@ class Directory(collections.abc.Hashable,
             to tell the filesystem what to copy where.
         """
         whereto = self.directory(pth=destination)
-        if any(whereto.exists, os.path.isfile(whereto.name),
-                               os.path.islink(whereto.name)):
+        if anyof(whereto.exists, os.path.isfile(whereto.name),
+                                 os.path.islink(whereto.name)):
             raise FilesystemError(
-                "copy_all() destination exists: %s" % whereto.name)
+                f"copy_all() destination exists: {whereto.name}")
         if self.exists:
-            return shutil.copytree(self.name, whereto.name)
+            return os.path.isdir(
+                   shutil.copytree(self.name, whereto.name,
+                                   symlinks=False))
         else:
             raise FilesystemError(
-                "copy_all() source doesn’t exist: %s" % self.name)
+                f"copy_all() source doesn’t exist: {self.name}")
         return False
     
     def zip_archive(self, zpth=None, zmode=None):
@@ -1054,7 +1059,7 @@ class Directory(collections.abc.Hashable,
         pth = self.subpath(filename, requisite=True)
         if not pth:
             raise KeyError(
-                "file not found: %s" % os.fspath(filename))
+                f"file not found: {os.fspath(filename)}")
         return pth
     
     def __contains__(self, filename):
@@ -1100,6 +1105,23 @@ class wd(Directory):
         """
         super(wd, self).__init__(pth=None)
 
+@export
+class td(Directory):
+    
+    def __init__(self):
+        """ Initialize a Directory instance for the current temporary directory.
+        """
+        from tempfile import gettempdir
+        super(td, self).__init__(pth=gettempdir())
+
+@export
+class hd(Directory):
+    
+    def __init__(self):
+        """ Initialize a Directory instance for the current user’s home directory.
+        """
+        super(hd, self).__init__(pth=os.path.expanduser("~"))
+
 @export
 class TemporaryDirectory(Directory):
     
@@ -1133,7 +1155,7 @@ class TemporaryDirectory(Directory):
         from tempfile import mkdtemp
         if suffix:
             if not suffix.startswith(os.extsep):
-                suffix = "%s%s" % (os.extsep, suffix)
+                suffix = f"{os.extsep}{suffix}"
         if parent is None:
             parent = kwargs.pop('dir', None)
         if parent:
@@ -1225,7 +1247,7 @@ class Intermediate(TemporaryDirectory, Directory):
         """
         if pth is not None:
             return Directory(pth=pth)
-        return TemporaryDirectory(prefix="%s-" % cls.__name__,
+        return TemporaryDirectory(prefix=f"{cls.__name__}-",
                                   change=False)
     
     def __init__(self, pth=None):
@@ -1252,9 +1274,9 @@ def NamedTemporaryFile(mode='w+b', buffer_size=-1,
     
     if suffix:
         if not suffix.startswith(os.extsep):
-            suffix = "%s%s" % (os.extsep, suffix)
+            suffix = f"{os.extsep}{suffix}"
     else:
-        suffix = "%stmp" % os.extsep
+        suffix = f"{os.extsep}tmp"
     
     if 'b' in mode:
         flags = _bin_openflags
