@@ -4,7 +4,7 @@ from __future__ import print_function
 import warnings
 
 from clu.constants.consts import BUILTINS, DEBUG, QUALIFIER
-from clu.exporting import determine_name, Exporter
+from clu.exporting import determine_name, path_to_dotpath, Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
@@ -84,7 +84,7 @@ def dotpath_join(base, *addenda):
             base += QUALIFIER
         if addendum.startswith(QUALIFIER):
             if len(addendum) == 1:
-                raise ValueError('operand too short: %s' % addendum)
+                raise ValueError(f'operand too short: {addendum}')
             addendum = addendum[1:]
         base += addendum
     # N.B. this might be overthinking it -- 
@@ -102,7 +102,7 @@ def dotpath_split(dotpath):
         `dotpath_split(…)` returns `(string, None)`.
     """
     head = dotpath.split(QUALIFIER)[-1]
-    tail = dotpath.replace("%s%s" % (QUALIFIER, head), '')
+    tail = dotpath.replace(f"{QUALIFIER}{head}", '')
     return head, tail != head and tail or None
 
 @export
@@ -112,12 +112,12 @@ def qualified_import(qualified):
     """
     import importlib
     if QUALIFIER not in qualified:
-        raise ValueError("qualified name required (got %s)" % qualified)
+        raise ValueError(f"qualified name required (got {qualified})")
     head, tail = dotpath_split(qualified)
     module = importlib.import_module(tail)
     imported = getattr(module, head)
     if DEBUG:
-        print("Qualified Import: %s" % qualified)
+        print(f"Qualified Import: {qualified}")
     return imported
 
 @export
@@ -137,9 +137,29 @@ def qualified_name(thing):
     mod_name, cls_name = qualified_name_tuple(thing)
     qualname = dotpath_join(mod_name, cls_name)
     if DEBUG:
-        print("Qualified Name: %s" % qualname)
+        print(f"Qualified Name: {qualname}")
     return qualname
 
+@export
+def dotpath_to_prefix(dotpath, sep='-', end='-'):
+    """ Convert a dotted path into a “prefix” string, suitable for
+        use with e.g. clu.fs.filesystem.TemporaryDirectory –
+        e.g. 'clu.typespace.namespace.SimpleNamespace' becomes:
+             'clu-typespace-namespace-simplenamespace-'
+    """
+    if any(c is None for c in (sep, end)):
+        raise ValueError(f"“sep” and “end” must be non-None (sep={sep}, end={end})")
+    if not dotpath:
+        raise ValueError(f"“dotpath” cannot be None or zero-length (dotpath={dotpath})")
+    return dotpath.lower().replace(QUALIFIER, sep) + end
+
+@export
+def path_to_prefix(path, sep='-', end='-'):
+    """ Shortcut for dotpath_to_prefix(path_to_dotpath(…)) """
+    return dotpath_to_prefix(path_to_dotpath(path),
+                             sep=sep,
+                             end=end)
+
 @export
 def split_abbreviations(s):
     """ Split a string into a tuple of its unique constituents,
