@@ -3,12 +3,14 @@ from __future__ import print_function
 
 import os
 import re
-import sys
 
-from clu.constants import DYNAMIC_MODULE_PREFIX, PROJECT_NAME, VERBOTEN, cache_from_source
+from clu.constants.consts import DYNAMIC_MODULE_PREFIX, PROJECT_NAME, VERBOTEN
+from clu.constants.polyfills import cache_from_source
 from .namespace import SimpleNamespace, Namespace
-from clu.exporting import doctrim, path_to_dotpath
-from clu.naming import dotpath_join
+from clu.exporting import Exporter
+
+exporter = Exporter(path=__file__)
+export = exporter.decorator()
 
 import types as thetypes
 types = Namespace()
@@ -37,14 +39,18 @@ setattr(types, '__cached__',      cache_from_source(__file__))
 setattr(types, '__package__',     os.path.splitext(
                                   os.path.basename(__file__))[0])
 
+@export
 def modulize(name, namespace, docs=None,
                               path=None):
     """ Convert a dictionary mapping into a legit Python module """
+    from clu.exporting import doctrim, path_to_dotpath
+    from clu.naming import dotpath_join
+    import sys
     
     # Ensure a module with the given module name we received
     # doesn’t already exist in `sys.modules`:
     if name in sys.modules:
-        raise LookupError("Module “%s” already in sys.modules" % name)
+        raise LookupError(f"Module “{name}” already in sys.modules")
     
     # Update the namespace with '__all__' and '__dir__' if necessary:
     ns_all = None
@@ -104,5 +110,15 @@ def modulize(name, namespace, docs=None,
     # Return our new module instance:
     return module
 
-__all__ = ('SimpleNamespace', 'Namespace', 'types', 'modulize')
-__dir__ = lambda: list(__all__)
\ No newline at end of file
+export(types,           name='types',       doc=""" A Namespace instance containing aliases into the `types` module,
+                                                    sans the irritating and lexically unnecessary “Type” suffix --
+                                                    e.g. `types.ModuleType` can be accessed as just `types.Module`
+                                                    from this Namespace, which is less pointlessly redundant and far
+                                                    more typographically pleasing, like definitively.
+                                                """)
+
+export(SimpleNamespace)
+export(Namespace)
+
+# Assign the modules’ `__all__` and `__dir__` using the exporter:
+__all__, __dir__ = exporter.all_and_dir()
