@@ -12,11 +12,13 @@ from clu.constants.consts import (BASEPATH,
                                   LAMBDA, λ,
                                   MAXINT,
                                   PATH,
-                                  PROJECT_NAME,
+                                  PARTIAL, φ,
+                                  PROJECT_NAME, PROJECT_PATH,
                                   PY3, PYPY,
                                   QUALIFIER,
                                   SEPARATOR_WIDTH,
                                   SINGLETON_TYPES,
+                                  SCRIPT_PATH, TEST_PATH,
                                   TEXTMATE,
                                   TOKEN,
                                   VERBOTEN,
@@ -24,6 +26,7 @@ from clu.constants.consts import (BASEPATH,
                                                     XDG_RUNTIME_MODE,
                                   NoDefault, pytuple)
 
+from clu.constants.data import GREEKOUT
 from clu.constants.enums import (System, CSIDL, SYSTEM)
 
 from clu.constants.exceptions import (BadDotpathWarning,
@@ -58,17 +61,18 @@ from clu.sanitizer import sanitize, sanitizers, utf8_encode, utf8_decode
 from clu.version import version_info
 
 from clu.predicates import (negate,
-                            ismetaclass, isclass, isclasstype,
+                            ismetaclass, isclass, isclasstype, metaclass,
                             noattr, haspyattr, nopyattr,
                             anyattrs, allattrs, noattrs,
                             anypyattrs, allpyattrs, nopyattrs,
                             haslength,
                             isiterable, ismergeable,
                             always, never, nuhuh,
-                            no_op, or_none,
+                            no_op, or_none, resolve,
                             getpyattr, getitem,
-                            accessor, searcher,
+                            accessor, collator, searcher,
                             attr, pyattr, item,
+                            attrs, pyattrs, items,
                             attr_search, pyattr_search, item_search,
                             isenum, enumchoices,
                             isaliasdescriptor, hasmembers, hasaliases,
@@ -77,7 +81,7 @@ from clu.predicates import (negate,
                             isexpandable, isnormative, iscontainer,
                             lambda_repr,
                             apply_to,
-                            predicate_all, predicate_any,
+                            predicate_all, predicate_any, predicate_none,
                             predicate_and, predicate_or, predicate_xor,
                             thing_has, class_has,
                             isslotted, isdictish, isslotdicty, slots_for,
@@ -87,25 +91,31 @@ from clu.predicates import (negate,
 
 from clu.typespace import SimpleNamespace, Namespace, types, modulize
 
-from clu.typology import (isunique, istypelist, maketypelist,
+from clu.typology import (samelength, differentlength, isunique, istypelist, maketypelist,
                           isderivative, subclasscheck, graceful_issubclass,
                           numeric_types, array_types, scalar_types, string_types, bytes_types,
-                          path_classes, path_types, file_types, function_types, Λ, callable_types,
+                          path_classes, path_types, file_types,
+                          dict_types, mapping_types, mapping_classes,
+                          function_types, Λ, callable_types,
                           ispathtype, ispath, isvalidpath,
                           isabstractmethod, isabstract, isabstractcontextmanager, iscontextmanager,
                           isnumber, isnumeric, iscomplex, isarray, isscalar, isstring, isbytes, ismodule,
-                          isfunction, ΛΛ, islambda, λλ, ishashable, issequence,
+                          isfunction, ΛΛ, islambda, λλ,
+                          iscallable, ishashable, issequence,
+                          isxlist, isxtypelist,
                           ispathtypelist, ispathlist, isvalidpathlist,
                           isnumberlist, isnumericlist, iscomplexlist,
                           isarraylist, isscalarlist, isstringlist, isbyteslist,
                           ismodulelist, isfunctionlist, islambdalist,
-                          ishashablelist, issequencelist)
+                          iscallablelist, ishashablelist, issequencelist)
 
 from clu.naming import (thingname, itermodule, moduleids, nameof,
                         determine_module,
                         dotpath_join, dotpath_split, qualified_import,
                                                      qualified_name_tuple,
-                                                     qualified_name, split_abbreviations)
+                                                     qualified_name,
+                        dotpath_to_prefix, path_to_prefix,
+                        split_abbreviations)
 
 from clu.dicts import merge_two, merge_as, merge, asdict
 
@@ -124,6 +134,7 @@ import functools
 import inspect
 import itertools
 import math
+import operator
 import requests
 import shutil
 import six
@@ -132,7 +143,10 @@ import termcolor
 import xerox
 
 from clu.mathematics import (σ, Σ,
-                             isdtype, isnumpything, isnumpytype,
+                             isdtype, isnumpything,
+                                      isnumpytype,
+                                      isnumpythinglist,
+                                      isnumpytypelist,
                              Clamper, clamp)
 
 from clu import keyvalue
@@ -147,15 +161,16 @@ from clu.repl.ansi import (print_separator, print_ansi, print_ansi_centered,
 from clu.repl.banners import print_banner
 
 # Compile all Greekly definitions and their names:
-GREEK_STRINGS = ('σ', 'Σ', 'λ', 'λλ', 'Λ', 'ΛΛ')
-GREEK_DEFS = (σ, Σ, λ, λλ, Λ, ΛΛ)
+GREEK_STRINGS = ('σ', 'Σ', 'λ', 'λλ', 'Λ', 'ΛΛ', 'φ')
+GREEK_DEFS = (σ, Σ, λ, λλ, Λ, ΛΛ, φ)
 
 GREEK_PHONETICS = ('sigma-lower',
                    'sigma-upper',
                    'lambda-lower',
                    'double-lambda-lower',
                    'lambda-upper',
-                   'double-lambda-upper')
+                   'double-lambda-upper',
+                   'phi-lower')
 
 GREEK_STRINGDICT = dict(zip(GREEK_STRINGS, GREEK_DEFS))
 GREEK_NAMEDICT = dict(zip(GREEK_PHONETICS, GREEK_DEFS))
@@ -176,6 +191,7 @@ __all__ = ('Image',
            'inspect',
            'itertools',
            'math',
+           'operator',
            'reduce',
            'requests',
            'shutil',
@@ -189,7 +205,7 @@ __all__ = ('Image',
                                           'GREEK_STRINGDICT',
                                           'GREEK_NAMEDICT',
            'σ', 'Σ',
-           'isdtype', 'isnumpything', 'isnumpytype',
+           'isdtype', 'isnumpything', 'isnumpytype', 'isnumpythinglist', 'isnumpytypelist',
            'Clamper', 'clamp',
            'predicates_for_types',
            'version_info',
@@ -204,17 +220,20 @@ __all__ = ('Image',
            'LAMBDA', 'λ',
            'MAXINT',
            'PATH',
-           'PROJECT_NAME',
+           'PARTIAL', 'φ',
+           'PROJECT_NAME', 'PROJECT_PATH',
            'PY3', 'PYPY',
            'QUALIFIER',
            'SEPARATOR_WIDTH',
            'SINGLETON_TYPES',
+           'SCRIPT_PATH', 'TEST_PATH',
            'TEXTMATE',
            'TOKEN',
            'VERBOTEN',
            'XDG_RUNTIME_BASE', 'XDG_RUNTIME_DIR',
                                'XDG_RUNTIME_MODE',
            'NoDefault',
+           'GREEKOUT',
            'System', 'CSIDL', 'SYSTEM',
            'BadDotpathWarning',
            'CDBError',
@@ -241,17 +260,18 @@ __all__ = ('Image',
            'predicates_for_types',
            'path_to_dotpath',
            'negate',
-           'ismetaclass', 'isclass', 'isclasstype',
+           'ismetaclass', 'isclass', 'isclasstype', 'metaclass',
            'noattr', 'haspyattr', 'nopyattr',
            'anyattrs', 'allattrs', 'noattrs',
            'anypyattrs', 'allpyattrs', 'nopyattrs',
            'haslength',
            'isiterable', 'ismergeable',
            'always', 'never', 'nuhuh',
-           'no_op', 'or_none',
+           'no_op', 'or_none', 'resolve',
            'getpyattr', 'getitem',
-           'accessor', 'searcher',
+           'accessor', 'collator', 'searcher',
            'attr', 'pyattr', 'item',
+           'attrs', 'pyattrs', 'items',
            'attr_search', 'pyattr_search', 'item_search',
            'isenum', 'enumchoices',
            'isaliasdescriptor', 'hasmembers', 'hasaliases',
@@ -260,7 +280,7 @@ __all__ = ('Image',
            'isexpandable', 'isnormative', 'iscontainer',
            'lambda_repr',
            'apply_to',
-           'predicate_all', 'predicate_any',
+           'predicate_all', 'predicate_any', 'predicate_none',
            'predicate_and', 'predicate_or', 'predicate_xor',
            'thing_has', 'class_has',
            'isslotted', 'isdictish', 'isslotdicty', 'slots_for',
@@ -268,25 +288,30 @@ __all__ = ('Image',
            'tuplize', 'uniquify', 'listify',
            'allof', 'anyof', 'noneof',
            'SimpleNamespace', 'Namespace', 'types', 'modulize',
-           'isunique', 'istypelist', 'maketypelist',
+           'samelength', 'differentlength', 'isunique', 'istypelist', 'maketypelist',
            'isderivative', 'subclasscheck', 'graceful_issubclass',
            'numeric_types', 'array_types', 'scalar_types', 'string_types', 'bytes_types',
-           'path_classes', 'path_types', 'file_types', 'function_types', 'Λ', 'callable_types',
+           'path_classes', 'path_types', 'file_types',
+           'dict_types', 'mapping_types', 'mapping_classes',
+           'function_types', 'Λ', 'callable_types',
            'ispathtype', 'ispath', 'isvalidpath',
            'isabstractmethod', 'isabstract', 'isabstractcontextmanager', 'iscontextmanager',
            'isnumber', 'isnumeric', 'iscomplex',
            'isarray', 'isscalar', 'isstring', 'isbytes',
            'ismodule', 'isfunction', 'ΛΛ', 'islambda', 'λλ',
-           'ishashable', 'issequence',
+           'iscallable', 'ishashable', 'issequence',
+           'isxlist', 'isxtypelist',
            'ispathtypelist', 'ispathlist', 'isvalidpathlist',
            'isnumberlist', 'isnumericlist', 'iscomplexlist',
            'isarraylist', 'isscalarlist', 'isstringlist', 'isbyteslist',
            'ismodulelist', 'isfunctionlist', 'islambdalist',
-           'ishashablelist', 'issequencelist',
+           'iscallablelist', 'ishashablelist', 'issequencelist',
            'thingname', 'itermodule', 'moduleids', 'slots_for', 'nameof',
            'determine_module',
            'dotpath_join', 'dotpath_split',
-           'qualified_import', 'qualified_name_tuple', 'qualified_name', 'split_abbreviations',
+           'qualified_import', 'qualified_name_tuple', 'qualified_name',
+           'dotpath_to_prefix', 'path_to_prefix',
+           'split_abbreviations',
            'merge_two', 'merge_as', 'merge', 'asdict',
            'DUNDER', 'SUNDER', 'alias', 'AliasingEnumMeta', 'AliasingEnum',
            'print_separator', 'print_ansi', 'print_ansi_centered',
@@ -339,7 +364,8 @@ try:
                                    ensure_path_is_valid,
                                    script_path, which, back_tick,
                                    rm_rf, temporary,
-                                   TemporaryName, Directory, cd, wd,
+                                   TemporaryName, Directory,
+                                                  cd, wd, td, hd,
                                    TemporaryDirectory, Intermediate,
                                    NamedTemporaryFile)
 except (ImportError, SyntaxError):
@@ -351,7 +377,8 @@ else:
                 'ensure_path_is_valid',
                 'script_path', 'which', 'back_tick',
                 'rm_rf', 'temporary',
-                'TemporaryName', 'Directory', 'cd', 'wd',
+                'TemporaryName', 'Directory',
+                                 'cd', 'wd', 'td', 'hd',
                 'TemporaryDirectory', 'Intermediate',
                 'NamedTemporaryFile')
 
