@@ -7,25 +7,22 @@ import contextlib
 import os
 import pytest
 
-from clu.fs import Directory
+from clu.fs.filesystem import Directory
 
 class TestFsFilesystem(object):
     
     """ Run the tests for the clu.fs.filesystem module. """
     
-    def test_zip_archive(self, shared_datadir):
+    def test_zip_archive(self, datadir):
         from clu.fs.filesystem import temporary
         from clu.typology import isvalidpathlist
         
-        # Ensure “shared_datadir” has something in it
-        # that we can use:
-        datafiles = tuple(shared_datadir.rglob("*.*"))
+        # Ensure the “datadir” fixture has something
+        # in it, of which we can make use:
+        datafiles = tuple(datadir.subpath(p) for p in datadir.ls_la())
         assert len(datafiles) > 0
         assert isvalidpathlist(datafiles)
         
-        # Create a Directory from the fixture-injected pathlib.Path:
-        datadir = Directory(shared_datadir)
-        
         # Use a temporary file path for the zip archive:
         tzip = temporary(prefix='test-zip-archive-',
                          suffix='zip',
@@ -52,54 +49,50 @@ class TestFsFilesystem(object):
         assert '.gitignore' in scripts
         assert '__init__.py' in scripts # it’s a Python module directory
     
-    def test_temporary(self):
+    def test_temporary(self, temporarydir):
         from clu.fs.filesystem import temporary, write_to_path
         from clu.constants.exceptions import FilesystemError
         
-        # Prepare the temporary directory:
-        d = Directory(gettempdir())
-        assert d.exists
-        
         # These automatically randomize:
-        assert temporary(dir=d).startswith(gettempdir())
-        assert temporary(parent=d).startswith(gettempdir())
+        assert temporary(dir=temporarydir).startswith(temporarydir.name)
+        assert temporary(parent=temporarydir).startswith(temporarydir.name)
         
         # These are deterministic:
-        prefix = os.path.join(gettempdir(), 'yo-dogg')
-        assert temporary(prefix='yo-dogg', dir=d) == prefix
-        assert temporary(prefix='yo-dogg', parent=d) == prefix
+        prefix = os.path.join(temporarydir.name, 'yo-dogg')
+        assert temporary(prefix='yo-dogg', dir=temporarydir) == prefix
+        assert temporary(prefix='yo-dogg', parent=temporarydir) == prefix
         
         # These are deterministic (see below):
-        prefix_suffix = os.path.join(gettempdir(), 'yo-dogg.tmp')
-        assert temporary(prefix='yo-dogg', suffix='tmp', dir=d) == prefix_suffix
-        assert temporary(prefix='yo-dogg', suffix='tmp', parent=d) == prefix_suffix
-        assert temporary(prefix='yo-dogg', suffix='.tmp', dir=d) == prefix_suffix
-        assert temporary(prefix='yo-dogg', suffix='.tmp', parent=d) == prefix_suffix
+        prefix_suffix = os.path.join(temporarydir.name, 'yo-dogg.tmp')
+        assert temporary(prefix='yo-dogg', suffix='tmp', dir=temporarydir) == prefix_suffix
+        assert temporary(prefix='yo-dogg', suffix='tmp', parent=temporarydir) == prefix_suffix
+        assert temporary(prefix='yo-dogg', suffix='.tmp', dir=temporarydir) == prefix_suffix
+        assert temporary(prefix='yo-dogg', suffix='.tmp', parent=temporarydir) == prefix_suffix
         
         # These are manually randomized:
-        starts = os.path.join(gettempdir(), 'yo-dogg-')
+        starts = os.path.join(temporarydir.name, 'yo-dogg-')
         ends = '.tmp'
         
         assert temporary(prefix='yo-dogg-',
                          suffix='tmp',
                          randomized=True,
-                         dir=d).startswith(starts)
+                         dir=temporarydir).startswith(starts)
         assert temporary(prefix='yo-dogg-',
                          suffix='tmp',
                          randomized=True,
-                         parent=d).startswith(starts)
+                         parent=temporarydir).startswith(starts)
         
         assert temporary(prefix='yo-dogg-',
                          suffix='tmp',
                          randomized=True,
-                         dir=d).endswith(ends)
+                         dir=temporarydir).endswith(ends)
         assert temporary(prefix='yo-dogg-',
                          suffix='tmp',
                          randomized=True,
-                         parent=d).endswith(ends)
+                         parent=temporarydir).endswith(ends)
         
         # Prepare the subpath
-        p = d.subpath('yo-dogg.tmp')
+        p = temporarydir.subpath('yo-dogg.tmp')
         assert not os.path.exists(p)
         
         # Prepare data:
@@ -120,19 +113,19 @@ class TestFsFilesystem(object):
             # in the computation of a file path that already exists –
             # see also the original forms of the deterministic calls, above:
             with pytest.raises(FilesystemError) as exc:
-                temporary(prefix='yo-dogg', suffix='tmp', dir=d)
+                temporary(prefix='yo-dogg', suffix='tmp', dir=temporarydir)
             assert "file exists" in str(exc.value)
             
             with pytest.raises(FilesystemError) as exc:
-                temporary(prefix='yo-dogg', suffix='tmp', parent=d)
+                temporary(prefix='yo-dogg', suffix='tmp', parent=temporarydir)
             assert "file exists" in str(exc.value)
             
             with pytest.raises(FilesystemError) as exc:
-                temporary(prefix='yo-dogg', suffix='.tmp', dir=d)
+                temporary(prefix='yo-dogg', suffix='.tmp', dir=temporarydir)
             assert "file exists" in str(exc.value)
             
             with pytest.raises(FilesystemError) as exc:
-                temporary(prefix='yo-dogg', suffix='.tmp', parent=d)
+                temporary(prefix='yo-dogg', suffix='.tmp', parent=temporarydir)
             assert "file exists" in str(exc.value)
         
         finally:
@@ -140,16 +133,12 @@ class TestFsFilesystem(object):
         
         assert not os.path.exists(p)
     
-    def test_rm_rf(self):
+    def test_rm_rf(self, temporarydir):
         # Also involves `write_to_path(…)` and `Directory.walk()`
         from clu.fs.filesystem import write_to_path, rm_rf
         
-        # Prepare the temporary directory:
-        d = Directory(gettempdir())
-        assert d.exists
-        
         # Make subdirectories:
-        dd = d.subdirectory('yo')
+        dd = temporarydir.subdirectory('yo')
         dd.makedirs()
         ddd = dd.subdirectory('dogg')
         ddd.makedirs()
@@ -216,17 +205,13 @@ class TestFsFilesystem(object):
                     'bumpversion')
         
         for binary in BINARIES:
-            assert which(binary) == back_tick("which %s" % binary)
+            assert which(binary) == back_tick(f"which {binary}")
     
-    def test_write_to_path(self):
+    def test_write_to_path(self, temporarydir):
         from clu.fs.filesystem import write_to_path
         
-        # Prepare the temporary directory:
-        d = Directory(gettempdir())
-        assert d.exists
-        
         # Prepare a new file subpath:
-        p = d.subpath('yodogg.txt')
+        p = temporarydir.subpath('yodogg.txt')
         assert not os.path.exists(p)
         
         # Prepare some data:
@@ -251,7 +236,7 @@ class TestFsFilesystem(object):
         
         assert not os.path.exists(p)
     
-    def test_ensure_path_is_valid(self):
+    def test_ensure_path_is_valid(self, temporarydir):
         from clu.constants.exceptions import FilesystemError
         from clu.fs.filesystem import ensure_path_is_valid
         from clu.fs.filesystem import NamedTemporaryFile
@@ -275,9 +260,8 @@ class TestFsFilesystem(object):
                 ensure_path_is_valid(tf.name)
             assert "file exists" in str(exc.value)
         
-        d = Directory(gettempdir())
-        p = d.subdirectory('a/b')
-        assert d.exists
+        p = temporarydir.subdirectory('a/b')
+        assert temporarydir.exists
         assert not p.exists
         
         with pytest.raises(FilesystemError) as exc:
@@ -285,8 +269,8 @@ class TestFsFilesystem(object):
         assert "Directory" in str(exc.value)
         
         # This one should be sucessful (as in it will not raise):
-        ensure_path_is_valid(d.subpath('yodogg.txt'))
-        assert not os.path.exists(d.subpath('yodogg.txt'))
+        ensure_path_is_valid(temporarydir.subpath('yodogg.txt'))
+        assert not os.path.exists(temporarydir.subpath('yodogg.txt'))
     
     def test_TemporaryName(self):
         """ Tests for clu.fs.filesystem.TemporaryName """
@@ -402,6 +386,70 @@ class TestFsFilesystem(object):
             assert os.path.isdir(os.fspath(tmp))
             assert tmp.basename in tmp.dirname
     
+    def test_td(self):
+        """ Tests for clu.fs.filesystem.td """
+        from clu.fs.filesystem import td
+        initial = os.getcwd()
+        
+        with td() as tmp:
+            # print("* Testing directory-change instance: %s" % tmp.name)
+            assert os.path.samefile(os.getcwd(),          gettempdir())
+            assert os.path.samefile(os.getcwd(),          tmp.new)
+            assert os.path.samefile(gettempdir(),         tmp.new)
+            assert os.path.samefile(os.getcwd(),          os.fspath(tmp))
+            assert os.path.samefile(gettempdir(),         os.fspath(tmp))
+            assert not os.path.samefile(os.getcwd(),      initial)
+            assert not os.path.samefile(tmp.new,          initial)
+            assert not os.path.samefile(os.fspath(tmp),   initial)
+            assert os.path.samefile(tmp.old,              initial)
+            assert tmp.will_change
+            assert tmp.did_change
+            assert tmp.will_change_back
+            assert not tmp.did_change_back
+            assert type(tmp.directory(tmp.new)) == Directory
+            assert isinstance(tmp,                        td)
+            assert isinstance(tmp,                        Directory)
+            assert isinstance(tmp,                        collections.abc.Hashable)
+            assert isinstance(tmp,                        collections.abc.Mapping)
+            assert isinstance(tmp,                        collections.abc.Sized)
+            assert isinstance(tmp,                        contextlib.AbstractContextManager)
+            assert isinstance(tmp,                        os.PathLike)
+            assert os.path.isdir(os.fspath(tmp))
+            assert tmp.basename in tmp.dirname
+    
+    def test_hd(self):
+        """ Tests for clu.fs.filesystem.hd """
+        from clu.fs.filesystem import hd
+        initial = os.getcwd()
+        
+        gethomedir = lambda: os.path.expanduser("~")
+        
+        with hd() as home:
+            # print("* Testing directory-change instance: %s" % tmp.name)
+            assert os.path.samefile(os.getcwd(),          gethomedir())
+            assert os.path.samefile(os.getcwd(),          home.new)
+            assert os.path.samefile(gethomedir(),         home.new)
+            assert os.path.samefile(os.getcwd(),          os.fspath(home))
+            assert os.path.samefile(gethomedir(),         os.fspath(home))
+            assert not os.path.samefile(os.getcwd(),      initial)
+            assert not os.path.samefile(home.new,         initial)
+            assert not os.path.samefile(os.fspath(home),  initial)
+            assert os.path.samefile(home.old,             initial)
+            assert home.will_change
+            assert home.did_change
+            assert home.will_change_back
+            assert not home.did_change_back
+            assert type(home.directory(home.new)) == Directory
+            assert isinstance(home,                        hd)
+            assert isinstance(home,                        Directory)
+            assert isinstance(home,                        collections.abc.Hashable)
+            assert isinstance(home,                        collections.abc.Mapping)
+            assert isinstance(home,                        collections.abc.Sized)
+            assert isinstance(home,                        contextlib.AbstractContextManager)
+            assert isinstance(home,                        os.PathLike)
+            assert os.path.isdir(os.fspath(home))
+            assert home.basename in home.dirname
+    
     def test_TemporaryDirectory(self):
         """ Tests for clu.fs.filesystem.TemporaryDirectory """
         from clu.fs.filesystem import TemporaryDirectory
