@@ -7,6 +7,127 @@ class TestPredicates(object):
     
     """ Run the tests for the clu.predicates module. """
     
+    def test_resolve_accessor(self):
+        from clu.predicates import resolve
+        from clu.typespace.namespace import SimpleNamespace
+        
+        ns = SimpleNamespace(yo=SimpleNamespace(
+                           dogg=SimpleNamespace(
+                         iheard=SimpleNamespace(
+                        youlike="namespaces"))))
+        
+        assert type(ns) is SimpleNamespace
+        assert type(ns.yo) is SimpleNamespace
+        assert type(ns.yo.dogg) is SimpleNamespace
+        assert type(ns.yo.dogg.iheard) is SimpleNamespace
+        assert type(ns.yo.dogg.iheard.youlike) is str
+        
+        assert type(resolve(ns, 'yo')) is SimpleNamespace
+        assert type(resolve(ns, 'yo.dogg')) is SimpleNamespace
+        assert type(resolve(ns, 'yo.dogg.iheard')) is SimpleNamespace
+        assert type(resolve(ns, 'yo.dogg.iheard.youlike')) is str
+        
+        assert resolve(ns, 'yo.dogg.iheard.youlike') == "namespaces"
+        assert resolve(ns, 'yo.dogg.iheard.youlike') == ns.yo.dogg.iheard.youlike
+    
+    def test_collator_based_accessors(self):
+        from clu.predicates import attr_across, pyattr_across, item_across
+        from clu.typespace.namespace import Namespace
+        
+        ns0 = Namespace(yo="Yo Dogg,",
+                        dogg="I heard you like",
+                        iheard="multidimentional accessors",
+                        youlike=None)
+        
+        ns1 = Namespace(yo="Yo Dogg,",
+                        dogg="I heard you like",
+                        iheard="polymorpic descriptors",
+                        youlike=None)
+        
+        ns2 = Namespace(yo="Yo Dogg,",
+                        dogg="I heard you like",
+                        iheard="attribute hypergetters",
+                        youlike=None)
+        
+        ns3 = Namespace(yo="Yo Dogg,",
+                        dogg="I heard you like",
+                        iheard="object-instance query functors",
+                        youlike=None)
+        
+        # Check “attr_across(…)”:
+        assert attr_across('yo', ns0, ns1, ns2, ns3) == ("Yo Dogg,",) * 4
+        assert attr_across('dogg', ns0, ns1, ns2, ns3) == ("I heard you like",) * 4
+        assert attr_across('iheard', ns0, ns1, ns2, ns3) == ("multidimentional accessors",
+                                                             "polymorpic descriptors",
+                                                             "attribute hypergetters",
+                                                             "object-instance query functors")
+        # “youlike” will be None, which won’t get collated:
+        assert attr_across('youlike', ns0, ns1, ns2, ns3) == tuple()
+        
+        # Check “item_across(…)”:
+        assert item_across('yo', ns0, ns1, ns2, ns3) == ("Yo Dogg,",) * 4
+        assert item_across('dogg', ns0, ns1, ns2, ns3) == ("I heard you like",) * 4
+        assert item_across('iheard', ns0, ns1, ns2, ns3) == ("multidimentional accessors",
+                                                             "polymorpic descriptors",
+                                                             "attribute hypergetters",
+                                                             "object-instance query functors")
+        # “youlike” will be None, which won’t get collated:
+        assert item_across('youlike', ns0, ns1, ns2, ns3) == tuple()
+        
+        # Check “pyattr_across(…)”:
+        assert pyattr_across('abstractmethods', ns0, ns1, ns2, ns3) == (frozenset(),) * 4
+        assert pyattr_across('class', ns0, ns1, ns2, ns3) == (Namespace,) * 4
+        assert pyattr_across('slots', ns0, ns1, ns2, ns3) == (tuple(),) * 4
+        # “__weakref__” will be None, which won’t get collated:
+        assert pyattr_across('weakref', ns0, ns1, ns2, ns3) == tuple()
+    
+    def test_acquirer_based_accessors(self):
+        from clu.predicates import attrs, pyattrs, items
+        from clu.typespace.namespace import Namespace
+        
+        ns = Namespace(yo="Yo Dogg,",
+                       dogg="I heard you like",
+                       iheard="irritating recursion",
+                       youlike=None)
+        
+        # Check “attrs(…)”:
+        assert attrs(ns, 'yo', 'dogg', 'iheard') == ("Yo Dogg,",
+                                                     "I heard you like",
+                                                     "irritating recursion")
+        
+        assert attrs(ns, 'iheard', 'dogg', 'yo') == ("irritating recursion",
+                                                     "I heard you like",
+                                                     "Yo Dogg,")
+        
+        # “youlike” will be None, which won’t get acquired:
+        assert attrs(ns, 'yo', 'dogg', 'iheard', 'youlike') == ("Yo Dogg,",
+                                                     "I heard you like",
+                                                     "irritating recursion")
+        
+        # Check “items(…)”:
+        assert items(ns, 'yo', 'dogg', 'iheard') == ("Yo Dogg,",
+                                                     "I heard you like",
+                                                     "irritating recursion")
+        
+        assert items(ns, 'iheard', 'dogg', 'yo') == ("irritating recursion",
+                                                     "I heard you like",
+                                                     "Yo Dogg,")
+        
+        # “youlike” will be None, which won’t get acquired:
+        assert items(ns, 'yo', 'dogg', 'iheard', 'youlike') == ("Yo Dogg,",
+                                                     "I heard you like",
+                                                     "irritating recursion")
+        
+        # Check “pyattrs(…)”:
+        assert pyattrs(ns, 'abstractmethods', 'class', 'module', 'slots') == (frozenset(), Namespace,
+                                                                             'clu.typespace.namespace',
+                                                                              tuple())
+        
+        # “__weakref__” will be None, which won’t get acquired:
+        assert pyattrs(ns, 'abstractmethods', 'class', 'module', 'slots', 'weakref') == (frozenset(), Namespace,
+                                                                             'clu.typespace.namespace',
+                                                                              tuple())
+    
     def test_utility_helpers_for_builtin_predicates(self):
         from clu.predicates import allof, anyof, noneof
         
@@ -150,6 +271,19 @@ class TestPredicates(object):
         from clu.typology import (numeric_types, string_types, bytes_types,
                                   callable_types, array_types, path_types)
         
+        # First, test apply_to(…) with invalid arguments (to raise a ValueError):
+        with pytest.raises(ValueError) as exc:
+            apply_to(isclasstype, "all")
+        assert "Noncallable passed to apply_to" in str(exc.value)
+        
+        with pytest.raises(ValueError) as exc:
+            apply_to("isclasstype", all)
+        assert "Noncallable passed to apply_to" in str(exc.value)
+        
+        with pytest.raises(ValueError) as exc:
+            apply_to("isclasstype", "all")
+        assert "Noncallable passed to apply_to" in str(exc.value)
+        
         # Test apply_to(…) returning a partial --
         # N.B. this is the exact implementation of actual functions
         # in use in clu.typology:
@@ -186,7 +320,7 @@ class TestPredicates(object):
     def test_applyto_predicate_logicals(self):
         """ » Checking “apply_to(…)” derived predicate logicals from clu.predicates … """
         from clu.predicates import (haslength, uncallable, isiterable, isslotted)
-        from clu.predicates import (predicate_all, predicate_any,
+        from clu.predicates import (predicate_all, predicate_any, predicate_none,
                                     predicate_and, predicate_or,
                                     predicate_xor)
         
@@ -209,9 +343,11 @@ class TestPredicates(object):
         assert predicate_all(isiterable, ttup, mseq, rstr, byts)
         assert predicate_all(uncallable, slot, ttup, mseq, rstr, byts)
         assert predicate_any(isslotted, slot, ttup, mseq, rstr, byts)
+        assert predicate_none(isslotted, ttup, mseq, rstr, byts)
         assert predicate_all(isiterable, rstr, byts, slot.yo, slot.dogg, slot.wtf)
         assert predicate_all(lambda thing: not uncallable(thing), Slotted, call, type)
         assert predicate_any(lambda thing: not uncallable(thing), Slotted, call, type, slot)
+        assert predicate_none(uncallable, Slotted, call, type)
         
         # Booleans:
         assert predicate_and(lambda thing: type(thing) is str, slot.yo, slot.dogg)
@@ -535,8 +671,11 @@ class TestPredicates(object):
                                   'name', 'hash', 'dir')
     
     def test_class_predicates(self):
-        """ » Checking “ismetaclass/isclass/isclasstype” from clu.predicates … """
-        from clu.predicates import ismetaclass, isclass, isclasstype
+        """ » Checking “ismetaclass/isclass/isclasstype/metaclass” from clu.predicates … """
+        from clu.predicates import (ismetaclass,
+                                    isclass,
+                                    isclasstype,
+                                    metaclass)
         
         class Class(object):
             pass
@@ -544,10 +683,17 @@ class TestPredicates(object):
         class MetaClass(type):
             pass
         
+        class ClassWithMeta(Class, metaclass=MetaClass):
+            pass
+        
         assert isclass(Class)
         assert isclasstype(Class)
         assert not ismetaclass(Class)
         
+        assert isclass(ClassWithMeta)
+        assert isclasstype(ClassWithMeta)
+        assert not ismetaclass(ClassWithMeta)
+        
         assert ismetaclass(MetaClass)
         assert isclasstype(MetaClass)
         assert not isclass(MetaClass)
@@ -555,6 +701,14 @@ class TestPredicates(object):
         assert not isclass(Class())
         assert not ismetaclass(Class())
         assert not isclasstype(Class())
+        
+        # Check the results of “metaclass(…)”:
+        assert metaclass(Class) is type
+        assert metaclass(MetaClass) is MetaClass
+        assert metaclass(ClassWithMeta) is MetaClass
+        
+        assert metaclass(Class()) is type
+        assert metaclass(ClassWithMeta()) is MetaClass
     
     def test_attr_accessor(self):
         """ » Checking “attr(•) accessor from clu.predicates …” """
@@ -582,64 +736,3 @@ class TestPredicates(object):
         hax = attr(plistlib, 'yo_dogg', 'wtf_hax', default=jon_snow)
         assert hax is jon_snow
         assert uncallable(hax)
-    
-    def test_boolean_predicates(self):
-        """ » Checking basic isXXX(•) functions from clu.typology … """
-        import array, decimal, os
-        from clu.predicates import attr
-        from clu.typespace import SimpleNamespace
-        from clu.typology import (subclasscheck,
-                                  ispathtype, ispath, isvalidpath,
-                                  isnumber, isnumeric, isarray,
-                                  isstring, isbytes,
-                                  islambda,
-                                  isfunction)
-        
-        assert subclasscheck(int, int)
-        
-        if hasattr(os, 'PathLike'):
-            assert ispathtype(os.PathLike)
-        
-        assert ispathtype(str)
-        assert ispathtype(bytes)
-        assert not ispathtype(SimpleNamespace)
-        assert ispath('/yo/dogg')
-        assert not ispath(SimpleNamespace())
-        assert not isvalidpath('/yo/dogg')
-        assert isvalidpath('/')
-        assert isvalidpath('/private/tmp')
-        assert isvalidpath('~/')
-        
-        assert isnumber(int)
-        assert isnumber(decimal.Decimal)
-        assert isnumber(666)
-        assert not isnumber(str)
-        assert not isnumber("666")
-        assert isnumeric(int)
-        assert isnumeric(float)
-        assert isnumeric(1)
-        assert not isnumeric(bytes)
-        assert not isnumeric("2001e50")
-        
-        assert isarray(array.array)
-        assert isstring(str)
-        assert isstring("")
-        assert isbytes(bytes)
-        assert isbytes(bytearray)
-        assert isbytes(b"")
-        
-        assert islambda(lambda: None)
-        assert islambda(attr)
-        assert islambda(subclasscheck) # IT IS NOW DOGG
-        
-        assert isfunction(lambda: None)
-        assert isfunction(attr)
-        assert isfunction(subclasscheck)
-        assert not isfunction(SimpleNamespace())
-        assert isfunction(SimpleNamespace) # classes are callable!
-    
-    def test_numpy_predicates(self):
-        from clu.typology import isarray
-        numpy = pytest.importorskip('numpy')
-        assert isarray(numpy.ndarray)
-        assert isarray(numpy.array([0, 1, 2]))
